=== modified file 'dotgraph.py'
--- dotgraph.py	2005-09-20 18:44:22 +0000
+++ dotgraph.py	2005-09-20 20:32:04 +0000
@@ -77,11 +77,36 @@
     def __str__(self):
         return self.name
 
+class Edge(object):
+    def __init__(self, start, end, label=None):
+        object.__init__(self)
+        self.start = start
+        self.end = end
+        self.label = label
+
+    def dot(self):
+        attributes = []
+        if self.label is not None:
+            attributes.append(('label', self.label))
+        if len(attributes) > 0:
+            atlist = []
+            for key, value in attributes:
+                atlist.append("%s=\"%s\"" % (key, value))
+            pq = ' '.join(atlist)
+            op = "[%s]" % pq
+        else:
+            op = ""
+        return "%s->%s%s;" % (self.start.name, self.end.name, op)
+
+def make_edge(relation):
+    return Edge(relation[0], relation[1])
+
 def dot_output(relations):
     defined = set()
     yield "digraph G\n"
     yield "{\n"
     clusters = set()
+    edges = [make_edge(f) for f in relations]
     def rel_appropriate(start, end, cluster):
         if cluster is None:
             return (start.cluster is None and end.cluster is None) or \
@@ -89,11 +114,11 @@
         else:
             return start.cluster==cluster and end.cluster==cluster
 
-    for (start, end) in relations:
-        if start.cluster is not None:
-            clusters.add(start.cluster)
-        if end.cluster is not None:
-            clusters.add(end.cluster)
+    for edge in edges:
+        if edge.start.cluster is not None:
+            clusters.add(edge.start.cluster)
+        if edge.end.cluster is not None:
+            clusters.add(edge.end.cluster)
     clusters = list(clusters)
     clusters.append(None)
     for index, cluster in enumerate(clusters):
@@ -101,19 +126,19 @@
             yield "subgraph cluster_%s\n" % index
             yield "{\n"
             yield '    label="%s"\n' % cluster
-        for (start, end) in relations:
-            if start.name not in defined and start.cluster == cluster:
-                defined.add(start.name)
-                my_def = start.define()
-                if my_def is not None:
-                    yield "    %s;\n" % my_def
-            if end.name not in defined and end.cluster == cluster:
-                defined.add(end.name)
-                my_def = end.define()
-                if my_def is not None:
-                    yield "    %s;\n" % my_def
-            if rel_appropriate(start, end, cluster):
-                yield "    %s->%s;\n" % (start.name, end.name)
+        for edge in edges:
+            if edge.start.name not in defined and edge.start.cluster == cluster:
+                defined.add(edge.start.name)
+                my_def = edge.start.define()
+                if my_def is not None:
+                    yield "    %s\n" % my_def
+            if edge.end.name not in defined and edge.end.cluster == cluster:
+                defined.add(edge.end.name)
+                my_def = edge.end.define()
+                if my_def is not None:
+                    yield "    %s;\n" % my_def
+            if rel_appropriate(edge.start, edge.end, cluster):
+                yield "    %s\n" % edge.dot()
         if cluster is not None:
             yield "}\n"
     yield "}\n"

